Creates a drop in replacement for cljs.repl/repl-read, since a readline can return multiple Clojure forms this function is stateful and buffers the forms and returns the next form on subsequent reads.
This function is a constructor that takes a line-reader and returns
a function that can replace cljs.repl/repl-read.
Example Usage:
(let [repl-env (nash/repl-env)] (cljs-repl/repl repl-env :prompt (fn []) :read (cljs-repl-read (rebel-readline.core/line-reader (rebel-readline-cljs.service/create {:repl-env repl-env}))])))
Creates a drop in replacement for cljs.repl/repl-read, since a
readline can return multiple Clojure forms this function is stateful
and buffers the forms and returns the next form on subsequent reads.
This function is a constructor that takes a line-reader and returns
a function that can replace `cljs.repl/repl-read`.
Example Usage:
(let [repl-env (nash/repl-env)]
(cljs-repl/repl
repl-env
:prompt (fn [])
:read (cljs-repl-read
(rebel-readline.core/line-reader
(rebel-readline-cljs.service/create {:repl-env repl-env}))])))(has-remaining? pbr)Takes a clojure.tools.reader.reader-types/SourceLoggingPushbackReader and returns true if there is another character in the stream. i.e not the end of the readers stream.
Takes a clojure.tools.reader.reader-types/SourceLoggingPushbackReader and returns true if there is another character in the stream. i.e not the end of the readers stream.
(repl repl-env & opts)(repl* repl-env opts)(syntax-highlight-println x)Print a syntax highlighted clojure value.
This printer respects the current color settings set in the service.
The rebel-readline.jline-api/*state* and
rebel-readline.jline-api/*service* dynamic vars have to be set for
this to work.
See rebel-readline-cljs.main for an example of how this function is normally used
Print a syntax highlighted clojure value. This printer respects the current color settings set in the service. The `rebel-readline.jline-api/*state*` and `rebel-readline.jline-api/*service*` dynamic vars have to be set for this to work. See `rebel-readline-cljs.main` for an example of how this function is normally used
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |